/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ADD_DOCUMENT_TASK_H_
#define _GB2_ADD_DOCUMENT_TASK_H_

#include <qpointer.h>
#include <core_api/Task.h>

namespace GB2 {
class Document;

// Adds document to the project. Waits for locks if any
class GB2_COREAPI_EXPORT AddDocumentTask : public Task {
    Q_OBJECT
public:
    AddDocumentTask( Document * d );
    virtual ReportResult report();
private:
    QPointer<Document> d;
};


}//namespace

#endif
